@@ -14,8 +14,8 @@
 import mock
 from mock import call
 
+from osc_lib.cli import format_columns
 from osc_lib import exceptions
-from osc_lib import utils
 
 from openstackclient.network.v2 import subnet as subnet_v2
 from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes_v3
@@ -38,160 +38,165 @@ class TestSubnet(network_fakes.TestNetworkV2):
 
 class TestCreateSubnet(TestSubnet):
 
-    project = identity_fakes_v3.FakeProject.create_one_project()
-    domain = identity_fakes_v3.FakeDomain.create_one_domain()
-    # An IPv4 subnet to be created with mostly default values
-    _subnet = network_fakes.FakeSubnet.create_one_subnet(
-        attrs={
-            'tenant_id': project.id,
-        }
-    )
-
-    # Subnet pool to be used to create a subnet from a pool
-    _subnet_pool = network_fakes.FakeSubnetPool.create_one_subnet_pool()
-
-    # An IPv4 subnet to be created using a specific subnet pool
-    _subnet_from_pool = network_fakes.FakeSubnet.create_one_subnet(
-        attrs={
-            'tenant_id': project.id,
-            'subnetpool_id': _subnet_pool.id,
-            'dns_nameservers': ['8.8.8.8',
-                                '8.8.4.4'],
-            'host_routes': [{'destination': '10.20.20.0/24',
-                             'nexthop': '10.20.20.1'},
-                            {'destination': '10.30.30.0/24',
-                             'nexthop': '10.30.30.1'}],
-            'service_types': ['network:router_gateway',
-                              'network:floatingip_agent_gateway'],
-        }
-    )
-
-    # An IPv6 subnet to be created with most options specified
-    _subnet_ipv6 = network_fakes.FakeSubnet.create_one_subnet(
-        attrs={
-            'tenant_id': project.id,
-            'cidr': 'fe80:0:0:a00a::/64',
-            'enable_dhcp': True,
-            'dns_nameservers': ['fe80:27ff:a00a:f00f::ffff',
-                                'fe80:37ff:a00a:f00f::ffff'],
-            'allocation_pools': [{'start': 'fe80::a00a:0:c0de:0:100',
-                                  'end': 'fe80::a00a:0:c0de:0:f000'},
-                                 {'start': 'fe80::a00a:0:c0de:1:100',
-                                  'end': 'fe80::a00a:0:c0de:1:f000'}],
-            'host_routes': [{'destination': 'fe80:27ff:a00a:f00f::/64',
-                             'nexthop': 'fe80:27ff:a00a:f00f::1'},
-                            {'destination': 'fe80:37ff:a00a:f00f::/64',
-                             'nexthop': 'fe80:37ff:a00a:f00f::1'}],
-            'ip_version': 6,
-            'gateway_ip': 'fe80::a00a:0:c0de:0:1',
-            'ipv6_address_mode': 'slaac',
-            'ipv6_ra_mode': 'slaac',
-            'subnetpool_id': 'None',
-            'service_types': ['network:router_gateway',
-                              'network:floatingip_agent_gateway'],
-        }
-    )
-
-    # The network to be returned from find_network
-    _network = network_fakes.FakeNetwork.create_one_network(
-        attrs={
-            'id': _subnet.network_id,
-        }
-    )
-
-    # The network segment to be returned from find_segment
-    _network_segment = \
-        network_fakes.FakeNetworkSegment.create_one_network_segment(
+    def _init_subnet_variables(self):
+        self.project = identity_fakes_v3.FakeProject.create_one_project()
+        self.domain = identity_fakes_v3.FakeDomain.create_one_domain()
+        # An IPv4 subnet to be created with mostly default values
+        self._subnet = network_fakes.FakeSubnet.create_one_subnet(
             attrs={
-                'network_id': _subnet.network_id,
+                'tenant_id': self.project.id,
             }
         )
 
-    columns = (
-        'allocation_pools',
-        'cidr',
-        'description',
-        'dns_nameservers',
-        'enable_dhcp',
-        'gateway_ip',
-        'host_routes',
-        'id',
-        'ip_version',
-        'ipv6_address_mode',
-        'ipv6_ra_mode',
-        'name',
-        'network_id',
-        'project_id',
-        'segment_id',
-        'service_types',
-        'subnetpool_id',
-        'tags',
-    )
+        # Subnet pool to be used to create a subnet from a pool
+        self._subnet_pool = \
+            network_fakes.FakeSubnetPool.create_one_subnet_pool()
 
-    data = (
-        subnet_v2._format_allocation_pools(_subnet.allocation_pools),
-        _subnet.cidr,
-        _subnet.description,
-        utils.format_list(_subnet.dns_nameservers),
-        _subnet.enable_dhcp,
-        _subnet.gateway_ip,
-        subnet_v2._format_host_routes(_subnet.host_routes),
-        _subnet.id,
-        _subnet.ip_version,
-        _subnet.ipv6_address_mode,
-        _subnet.ipv6_ra_mode,
-        _subnet.name,
-        _subnet.network_id,
-        _subnet.project_id,
-        _subnet.segment_id,
-        utils.format_list(_subnet.service_types),
-        _subnet.subnetpool_id,
-        utils.format_list(_subnet.tags),
-    )
+        # An IPv4 subnet to be created using a specific subnet pool
+        self._subnet_from_pool = network_fakes.FakeSubnet.create_one_subnet(
+            attrs={
+                'tenant_id': self.project.id,
+                'subnetpool_id': self._subnet_pool.id,
+                'dns_nameservers': ['8.8.8.8',
+                                    '8.8.4.4'],
+                'host_routes': [{'destination': '10.20.20.0/24',
+                                 'nexthop': '10.20.20.1'},
+                                {'destination': '10.30.30.0/24',
+                                 'nexthop': '10.30.30.1'}],
+                'service_types': ['network:router_gateway',
+                                  'network:floatingip_agent_gateway'],
+            }
+        )
 
-    data_subnet_pool = (
-        subnet_v2._format_allocation_pools(_subnet_from_pool.allocation_pools),
-        _subnet_from_pool.cidr,
-        _subnet_from_pool.description,
-        utils.format_list(_subnet_from_pool.dns_nameservers),
-        _subnet_from_pool.enable_dhcp,
-        _subnet_from_pool.gateway_ip,
-        subnet_v2._format_host_routes(_subnet_from_pool.host_routes),
-        _subnet_from_pool.id,
-        _subnet_from_pool.ip_version,
-        _subnet_from_pool.ipv6_address_mode,
-        _subnet_from_pool.ipv6_ra_mode,
-        _subnet_from_pool.name,
-        _subnet_from_pool.network_id,
-        _subnet_from_pool.project_id,
-        _subnet_from_pool.segment_id,
-        utils.format_list(_subnet_from_pool.service_types),
-        _subnet_from_pool.subnetpool_id,
-        utils.format_list(_subnet.tags),
-    )
+        # An IPv6 subnet to be created with most options specified
+        self._subnet_ipv6 = network_fakes.FakeSubnet.create_one_subnet(
+            attrs={
+                'tenant_id': self.project.id,
+                'cidr': 'fe80:0:0:a00a::/64',
+                'enable_dhcp': True,
+                'dns_nameservers': ['fe80:27ff:a00a:f00f::ffff',
+                                    'fe80:37ff:a00a:f00f::ffff'],
+                'allocation_pools': [{'start': 'fe80::a00a:0:c0de:0:100',
+                                      'end': 'fe80::a00a:0:c0de:0:f000'},
+                                     {'start': 'fe80::a00a:0:c0de:1:100',
+                                      'end': 'fe80::a00a:0:c0de:1:f000'}],
+                'host_routes': [{'destination': 'fe80:27ff:a00a:f00f::/64',
+                                 'nexthop': 'fe80:27ff:a00a:f00f::1'},
+                                {'destination': 'fe80:37ff:a00a:f00f::/64',
+                                 'nexthop': 'fe80:37ff:a00a:f00f::1'}],
+                'ip_version': 6,
+                'gateway_ip': 'fe80::a00a:0:c0de:0:1',
+                'ipv6_address_mode': 'slaac',
+                'ipv6_ra_mode': 'slaac',
+                'subnetpool_id': 'None',
+                'service_types': ['network:router_gateway',
+                                  'network:floatingip_agent_gateway'],
+            }
+        )
 
-    data_ipv6 = (
-        subnet_v2._format_allocation_pools(_subnet_ipv6.allocation_pools),
-        _subnet_ipv6.cidr,
-        _subnet_ipv6.description,
-        utils.format_list(_subnet_ipv6.dns_nameservers),
-        _subnet_ipv6.enable_dhcp,
-        _subnet_ipv6.gateway_ip,
-        subnet_v2._format_host_routes(_subnet_ipv6.host_routes),
-        _subnet_ipv6.id,
-        _subnet_ipv6.ip_version,
-        _subnet_ipv6.ipv6_address_mode,
-        _subnet_ipv6.ipv6_ra_mode,
-        _subnet_ipv6.name,
-        _subnet_ipv6.network_id,
-        _subnet_ipv6.project_id,
-        _subnet_ipv6.segment_id,
-        utils.format_list(_subnet_ipv6.service_types),
-        _subnet_ipv6.subnetpool_id,
-        utils.format_list(_subnet.tags),
-    )
+        # The network to be returned from find_network
+        self._network = network_fakes.FakeNetwork.create_one_network(
+            attrs={
+                'id': self._subnet.network_id,
+            }
+        )
+
+        # The network segment to be returned from find_segment
+        self._network_segment = \
+            network_fakes.FakeNetworkSegment.create_one_network_segment(
+                attrs={
+                    'network_id': self._subnet.network_id,
+                }
+            )
+
+        self.columns = (
+            'allocation_pools',
+            'cidr',
+            'description',
+            'dns_nameservers',
+            'enable_dhcp',
+            'gateway_ip',
+            'host_routes',
+            'id',
+            'ip_version',
+            'ipv6_address_mode',
+            'ipv6_ra_mode',
+            'name',
+            'network_id',
+            'project_id',
+            'segment_id',
+            'service_types',
+            'subnetpool_id',
+            'tags',
+        )
+
+        self.data = (
+            subnet_v2.AllocationPoolsColumn(self._subnet.allocation_pools),
+            self._subnet.cidr,
+            self._subnet.description,
+            format_columns.ListColumn(self._subnet.dns_nameservers),
+            self._subnet.enable_dhcp,
+            self._subnet.gateway_ip,
+            subnet_v2.HostRoutesColumn(self._subnet.host_routes),
+            self._subnet.id,
+            self._subnet.ip_version,
+            self._subnet.ipv6_address_mode,
+            self._subnet.ipv6_ra_mode,
+            self._subnet.name,
+            self._subnet.network_id,
+            self._subnet.project_id,
+            self._subnet.segment_id,
+            format_columns.ListColumn(self._subnet.service_types),
+            self._subnet.subnetpool_id,
+            format_columns.ListColumn(self._subnet.tags),
+        )
+
+        self.data_subnet_pool = (
+            subnet_v2.AllocationPoolsColumn(
+                self._subnet_from_pool.allocation_pools),
+            self._subnet_from_pool.cidr,
+            self._subnet_from_pool.description,
+            format_columns.ListColumn(self._subnet_from_pool.dns_nameservers),
+            self._subnet_from_pool.enable_dhcp,
+            self._subnet_from_pool.gateway_ip,
+            subnet_v2.HostRoutesColumn(self._subnet_from_pool.host_routes),
+            self._subnet_from_pool.id,
+            self._subnet_from_pool.ip_version,
+            self._subnet_from_pool.ipv6_address_mode,
+            self._subnet_from_pool.ipv6_ra_mode,
+            self._subnet_from_pool.name,
+            self._subnet_from_pool.network_id,
+            self._subnet_from_pool.project_id,
+            self._subnet_from_pool.segment_id,
+            format_columns.ListColumn(self._subnet_from_pool.service_types),
+            self._subnet_from_pool.subnetpool_id,
+            format_columns.ListColumn(self._subnet_from_pool.tags),
+        )
+
+        self.data_ipv6 = (
+            subnet_v2.AllocationPoolsColumn(
+                self._subnet_ipv6.allocation_pools),
+            self._subnet_ipv6.cidr,
+            self._subnet_ipv6.description,
+            format_columns.ListColumn(self._subnet_ipv6.dns_nameservers),
+            self._subnet_ipv6.enable_dhcp,
+            self._subnet_ipv6.gateway_ip,
+            subnet_v2.HostRoutesColumn(self._subnet_ipv6.host_routes),
+            self._subnet_ipv6.id,
+            self._subnet_ipv6.ip_version,
+            self._subnet_ipv6.ipv6_address_mode,
+            self._subnet_ipv6.ipv6_ra_mode,
+            self._subnet_ipv6.name,
+            self._subnet_ipv6.network_id,
+            self._subnet_ipv6.project_id,
+            self._subnet_ipv6.segment_id,
+            format_columns.ListColumn(self._subnet_ipv6.service_types),
+            self._subnet_ipv6.subnetpool_id,
+            format_columns.ListColumn(self._subnet_ipv6.tags),
+        )
 
     def setUp(self):
+        self._init_subnet_variables()
         super(TestCreateSubnet, self).setUp()
 
         # Get the command object to test
@@ -250,7 +255,7 @@ class TestCreateSubnet(TestSubnet):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_create_from_subnet_pool_options(self):
         # Mock SDK calls for this test.
@@ -312,7 +317,7 @@ class TestCreateSubnet(TestSubnet):
             'service_types': self._subnet_from_pool.service_types,
         })
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data_subnet_pool, data)
+        self.assertItemEqual(self.data_subnet_pool, data)
 
     def test_create_options_subnet_range_ipv6(self):
         # Mock SDK calls for this test.
@@ -385,7 +390,7 @@ class TestCreateSubnet(TestSubnet):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data_ipv6, data)
+        self.assertItemEqual(self.data_ipv6, data)
 
     def test_create_with_network_segment(self):
         # Mock SDK calls for this test.
@@ -419,7 +424,7 @@ class TestCreateSubnet(TestSubnet):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_create_with_description(self):
         # Mock SDK calls for this test.
@@ -453,7 +458,7 @@ class TestCreateSubnet(TestSubnet):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def _test_create_with_tag(self, add_tags=True):
         arglist = [
@@ -492,7 +497,7 @@ class TestCreateSubnet(TestSubnet):
         else:
             self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
     def test_create_with_tags(self):
         self._test_create_with_tag(add_tags=True)
@@ -620,13 +625,13 @@ class TestListSubnet(TestSubnet):
             subnet.cidr,
             subnet.tenant_id,
             subnet.enable_dhcp,
-            utils.format_list(subnet.dns_nameservers),
-            subnet_v2._format_allocation_pools(subnet.allocation_pools),
-            utils.format_list(subnet.host_routes),
+            format_columns.ListColumn(subnet.dns_nameservers),
+            subnet_v2.AllocationPoolsColumn(subnet.allocation_pools),
+            subnet_v2.HostRoutesColumn(subnet.host_routes),
             subnet.ip_version,
             subnet.gateway_ip,
-            utils.format_list(subnet.service_types),
-            utils.format_list(subnet.tags),
+            format_columns.ListColumn(subnet.service_types),
+            format_columns.ListColumn(subnet.tags),
         ))
 
     def setUp(self):
@@ -648,7 +653,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with()
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_long(self):
         arglist = [
@@ -663,7 +668,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with()
         self.assertEqual(self.columns_long, columns)
-        self.assertEqual(self.data_long, list(data))
+        self.assertListItemEqual(self.data_long, list(data))
 
     def test_subnet_list_ip_version(self):
         arglist = [
@@ -679,7 +684,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_dhcp(self):
         arglist = [
@@ -695,7 +700,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_no_dhcp(self):
         arglist = [
@@ -711,7 +716,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_service_type(self):
         arglist = [
@@ -726,7 +731,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_project(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -744,7 +749,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_service_type_multiple(self):
         arglist = [
@@ -762,7 +767,7 @@ class TestListSubnet(TestSubnet):
                                      'network:floatingip_agent_gateway']}
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_project_domain(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -782,7 +787,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_network(self):
         network = network_fakes.FakeNetwork.create_one_network()
@@ -800,7 +805,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_gateway(self):
         subnet = network_fakes.FakeSubnet.create_one_subnet()
@@ -818,7 +823,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_name(self):
         subnet = network_fakes.FakeSubnet.create_one_subnet()
@@ -836,7 +841,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_subnet_list_subnet_range(self):
         subnet = network_fakes.FakeSubnet.create_one_subnet()
@@ -854,7 +859,7 @@ class TestListSubnet(TestSubnet):
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, list(data))
+        self.assertListItemEqual(self.data, list(data))
 
     def test_list_with_tag_options(self):
         arglist = [
@@ -1041,6 +1046,36 @@ class TestSetSubnet(TestSubnet):
             _testsubnet, **attrs)
         self.assertIsNone(result)
 
+    def test_clear_options(self):
+        _testsubnet = network_fakes.FakeSubnet.create_one_subnet(
+            {'host_routes': [{'destination': '10.20.20.0/24',
+                              'nexthop': '10.20.20.1'}],
+             'allocation_pools': [{'start': '8.8.8.200',
+                                   'end': '8.8.8.250'}],
+             'dns_nameservers': ['10.0.0.1'], })
+        self.network.find_subnet = mock.Mock(return_value=_testsubnet)
+        arglist = [
+            '--no-host-route',
+            '--no-allocation-pool',
+            '--no-dns-nameservers',
+            _testsubnet.name,
+        ]
+        verifylist = [
+            ('no_dns_nameservers', True),
+            ('no_host_route', True),
+            ('no_allocation_pool', True),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        result = self.cmd.take_action(parsed_args)
+        attrs = {
+            'host_routes': [],
+            'allocation_pools': [],
+            'dns_nameservers': [],
+        }
+        self.network.update_subnet.assert_called_once_with(
+            _testsubnet, **attrs)
+        self.assertIsNone(result)
+
     def _test_set_tags(self, with_tags=True):
         if with_tags:
             arglist = ['--tag', 'red', '--tag', 'blue']
@@ -1069,6 +1104,29 @@ class TestSetSubnet(TestSubnet):
     def test_set_with_no_tag(self):
         self._test_set_tags(with_tags=False)
 
+    def test_set_segment(self):
+        _net = network_fakes.FakeNetwork.create_one_network()
+        _segment = network_fakes.FakeNetworkSegment.create_one_network_segment(
+            attrs={'network_id': _net.id})
+        _subnet = network_fakes.FakeSubnet.create_one_subnet(
+            {'host_routes': [{'destination': '10.20.20.0/24',
+                              'nexthop': '10.20.20.1'}],
+             'allocation_pools': [{'start': '8.8.8.200',
+                                   'end': '8.8.8.250'}],
+             'dns_nameservers': ["10.0.0.1"],
+             'network_id': _net.id,
+             'segment_id': None})
+        self.network.find_subnet = mock.Mock(return_value=_subnet)
+        self.network.find_segment = mock.Mock(return_value=_segment)
+        arglist = ['--network-segment', _segment.id, _subnet.name]
+        verifylist = [('network_segment', _segment.id)]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        result = self.cmd.take_action(parsed_args)
+        attrs = {'segment_id': _segment.id}
+        self.network.update_subnet.assert_called_once_with(_subnet, **attrs)
+        self.network.update_subnet.assert_called_with(_subnet, **attrs)
+        self.assertIsNone(result)
+
 
 class TestShowSubnet(TestSubnet):
     # The subnets to be shown
@@ -1096,13 +1154,13 @@ class TestShowSubnet(TestSubnet):
     )
 
     data = (
-        subnet_v2._format_allocation_pools(_subnet.allocation_pools),
+        subnet_v2.AllocationPoolsColumn(_subnet.allocation_pools),
         _subnet.cidr,
         _subnet.description,
-        utils.format_list(_subnet.dns_nameservers),
+        format_columns.ListColumn(_subnet.dns_nameservers),
         _subnet.enable_dhcp,
         _subnet.gateway_ip,
-        utils.format_list(_subnet.host_routes),
+        subnet_v2.HostRoutesColumn(_subnet.host_routes),
         _subnet.id,
         _subnet.ip_version,
         _subnet.ipv6_address_mode,
@@ -1111,9 +1169,9 @@ class TestShowSubnet(TestSubnet):
         _subnet.network_id,
         _subnet.tenant_id,
         _subnet.segment_id,
-        utils.format_list(_subnet.service_types),
+        format_columns.ListColumn(_subnet.service_types),
         _subnet.subnetpool_id,
-        utils.format_list(_subnet.tags),
+        format_columns.ListColumn(_subnet.tags),
     )
 
     def setUp(self):
@@ -1148,7 +1206,7 @@ class TestShowSubnet(TestSubnet):
             self._subnet.name, ignore_missing=False)
 
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.data, data)
+        self.assertItemEqual(self.data, data)
 
 
 class TestUnsetSubnet(TestSubnet):
