@@ -16,6 +16,7 @@
 
 import logging
 
+from osc_lib.cli import format_columns
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
@@ -27,6 +28,60 @@ from openstackclient.i18n import _
 LOG = logging.getLogger(__name__)
 
 
+def _find_volumes(parsed_args_volumes, volume_client):
+    result = 0
+    uuid = ''
+    for volume in parsed_args_volumes:
+        try:
+            volume_id = utils.find_resource(
+                volume_client.volumes, volume).id
+            uuid += volume_id + ','
+        except Exception as e:
+            result += 1
+            LOG.error(_("Failed to find volume with "
+                        "name or ID '%(volume)s':%(e)s")
+                      % {'volume': volume, 'e': e})
+
+    return result, uuid
+
+
+class AddVolumeToConsistencyGroup(command.Command):
+    _description = _("Add volume(s) to consistency group")
+
+    def get_parser(self, prog_name):
+        parser = super(AddVolumeToConsistencyGroup, self).get_parser(prog_name)
+        parser.add_argument(
+            'consistency_group',
+            metavar="<consistency-group>",
+            help=_('Consistency group to contain <volume> (name or ID)'),
+        )
+        parser.add_argument(
+            'volumes',
+            metavar='<volume>',
+            nargs='+',
+            help=_('Volume(s) to add to <consistency-group> (name or ID) '
+                   '(repeat option to add multiple volumes)'),
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        volume_client = self.app.client_manager.volume
+        result, add_uuid = _find_volumes(parsed_args.volumes, volume_client)
+
+        if result > 0:
+            total = len(parsed_args.volumes)
+            LOG.error(_("%(result)s of %(total)s volumes failed "
+                      "to add.") % {'result': result, 'total': total})
+
+        if add_uuid:
+            add_uuid = add_uuid.rstrip(',')
+            consistency_group_id = utils.find_resource(
+                volume_client.consistencygroups,
+                parsed_args.consistency_group).id
+            volume_client.consistencygroups.update(
+                consistency_group_id, add_volumes=add_uuid)
+
+
 class CreateConsistencyGroup(command.ShowOne):
     _description = _("Create new consistency group.")
 
@@ -184,10 +239,48 @@ class ListConsistencyGroup(command.Lister):
         return (columns, (
             utils.get_item_properties(
                 s, columns,
-                formatters={'Volume Types': utils.format_list})
+                formatters={'Volume Types': format_columns.ListColumn})
             for s in consistency_groups))
 
 
+class RemoveVolumeFromConsistencyGroup(command.Command):
+    _description = _("Remove volume(s) from consistency group")
+
+    def get_parser(self, prog_name):
+        parser = \
+            super(RemoveVolumeFromConsistencyGroup, self).get_parser(prog_name)
+        parser.add_argument(
+            'consistency_group',
+            metavar="<consistency-group>",
+            help=_('Consistency group containing <volume> (name or ID)'),
+        )
+        parser.add_argument(
+            'volumes',
+            metavar='<volume>',
+            nargs='+',
+            help=_('Volume(s) to remove from <consistency-group> (name or ID) '
+                   '(repeat option to remove multiple volumes)'),
+        )
+        return parser
+
+    def take_action(self, parsed_args):
+        volume_client = self.app.client_manager.volume
+        result, remove_uuid = _find_volumes(parsed_args.volumes, volume_client)
+
+        if result > 0:
+            total = len(parsed_args.volumes)
+            LOG.error(_("%(result)s of %(total)s volumes failed "
+                      "to remove.") % {'result': result, 'total': total})
+
+        if remove_uuid:
+            remove_uuid = remove_uuid.rstrip(',')
+            consistency_group_id = utils.find_resource(
+                volume_client.consistencygroups,
+                parsed_args.consistency_group).id
+            volume_client.consistencygroups.update(
+                consistency_group_id, remove_volumes=remove_uuid)
+
+
 class SetConsistencyGroup(command.Command):
     _description = _("Set consistency group properties")
 
